ASAuthorizationControllerPresentationContextProviding

Trait ASAuthorizationControllerPresentationContextProviding 

pub unsafe trait ASAuthorizationControllerPresentationContextProviding: NSObjectProtocol + MainThreadOnly {
    // Provided method
    unsafe fn presentationAnchorForAuthorizationController(
        &self,
        controller: &ASAuthorizationController,
    ) -> Retained<ASPresentationAnchor>
       where Self: Sized + Message { ... }
}
Available on crate feature ASAuthorizationController only.
Provided Methods

unsafe fn presentationAnchorForAuthorizationController( &self, controller: &ASAuthorizationController, ) -> Retained<ASPresentationAnchor>
where Self: Sized + Message,

Available on macOS and crate feature ASFoundation only.

Return a view anchor that is most appropriate for athorization UI to be presented over. This view will be used as a hint if a credential provider requires user interaction.