ASAuthorizationPublicKeyCredentialRegistrationRequest

Trait ASAuthorizationPublicKeyCredentialRegistrationRequest 

pub unsafe trait ASAuthorizationPublicKeyCredentialRegistrationRequest:
    NSObjectProtocol
    + NSSecureCoding
    + NSCopying {
Show 13 methods // Provided methods unsafe fn relyingPartyIdentifier(&self) -> Retained<NSString> where Self: Sized + Message { ... } unsafe fn userID(&self) -> Retained<NSData> where Self: Sized + Message { ... } unsafe fn setUserID(&self, user_id: &NSData) where Self: Sized + Message { ... } unsafe fn name(&self) -> Retained<NSString> where Self: Sized + Message { ... } unsafe fn setName(&self, name: &NSString) where Self: Sized + Message { ... } unsafe fn displayName(&self) -> Option<Retained<NSString>> where Self: Sized + Message { ... } unsafe fn setDisplayName(&self, display_name: Option<&NSString>) where Self: Sized + Message { ... } unsafe fn challenge(&self) -> Retained<NSData> where Self: Sized + Message { ... } unsafe fn setChallenge(&self, challenge: &NSData) where Self: Sized + Message { ... } unsafe fn userVerificationPreference( &self, ) -> Retained<ASAuthorizationPublicKeyCredentialUserVerificationPreference> where Self: Sized + Message { ... } unsafe fn setUserVerificationPreference( &self, user_verification_preference: &ASAuthorizationPublicKeyCredentialUserVerificationPreference, ) where Self: Sized + Message { ... } unsafe fn attestationPreference( &self, ) -> Retained<ASAuthorizationPublicKeyCredentialAttestationKind> where Self: Sized + Message { ... } unsafe fn setAttestationPreference( &self, attestation_preference: &ASAuthorizationPublicKeyCredentialAttestationKind, ) where Self: Sized + Message { ... }
}
Available on crate feature ASAuthorizationPublicKeyCredentialRegistrationRequest only.
Provided Methods

unsafe fn relyingPartyIdentifier(&self) -> Retained<NSString>
where Self: Sized + Message,

The Relying Party identifier used to scope this request.

unsafe fn userID(&self) -> Retained<NSData>
where Self: Sized + Message,

An arbitrary byte sequence which will be stored alongside the credential and will be returned with the credential when authenticating with it in the future. May be used by a relying party to identify the user account this credential is associated with.

unsafe fn setUserID(&self, user_id: &NSData)
where Self: Sized + Message,

Setter for userID.

This is copied when set.

unsafe fn name(&self) -> Retained<NSString>
where Self: Sized + Message,

A human readable name to associate with a credential, which a user should be able to use to identify the credential.

unsafe fn setName(&self, name: &NSString)
where Self: Sized + Message,

Setter for name.

This is copied when set.

unsafe fn displayName(&self) -> Option<Retained<NSString>>
where Self: Sized + Message,

A high level human readable name to associate with a credential, which should only be used for display.

unsafe fn setDisplayName(&self, display_name: Option<&NSString>)
where Self: Sized + Message,

Setter for displayName.

This is copied when set.

unsafe fn challenge(&self) -> Retained<NSData>
where Self: Sized + Message,

The challenge which can be used to verify the authenticator’s attestation, if attestation is requested.

unsafe fn setChallenge(&self, challenge: &NSData)
where Self: Sized + Message,

Setter for challenge.

This is copied when set.

unsafe fn userVerificationPreference( &self, ) -> Retained<ASAuthorizationPublicKeyCredentialUserVerificationPreference>
where Self: Sized + Message,

Available on crate feature ASAuthorizationPublicKeyCredentialConstants only.

A preference for whether the authenticator should attempt to verify that it is being used by its owner, such as through a PIN or biometrics.

unsafe fn setUserVerificationPreference( &self, user_verification_preference: &ASAuthorizationPublicKeyCredentialUserVerificationPreference, )
where Self: Sized + Message,

Available on crate feature ASAuthorizationPublicKeyCredentialConstants only.
unsafe fn attestationPreference( &self, ) -> Retained<ASAuthorizationPublicKeyCredentialAttestationKind>
where Self: Sized + Message,

Available on crate feature ASAuthorizationPublicKeyCredentialConstants only.

A preference for the type of attestation that the authenticator should attempt to perform.

unsafe fn setAttestationPreference( &self, attestation_preference: &ASAuthorizationPublicKeyCredentialAttestationKind, )
where Self: Sized + Message,

Available on crate feature ASAuthorizationPublicKeyCredentialConstants only.