pub unsafe trait ASAuthorizationControllerPresentationContextProviding: NSObjectProtocol + MainThreadOnly {
// Provided method
unsafe fn presentationAnchorForAuthorizationController(
&self,
controller: &ASAuthorizationController,
) -> Retained<ASPresentationAnchor>
where Self: Sized + Message { ... }
}Available on crate feature
ASAuthorizationController only.Expand description
Provided Methods
Sourceunsafe fn presentationAnchorForAuthorizationController(
&self,
controller: &ASAuthorizationController,
) -> Retained<ASPresentationAnchor>
Available on macOS and crate feature ASFoundation only.
unsafe fn presentationAnchorForAuthorizationController( &self, controller: &ASAuthorizationController, ) -> Retained<ASPresentationAnchor>
ASFoundation only.Return a view anchor that is most appropriate for athorization UI to be presented over. This view will be used as a hint if a credential provider requires user interaction.